==> http-2.5-sources.jar: net/codestory/http/reload/ConfigurationReloadingProxy.java <==
/**
 * Copyright (C) 2013 all@code-story.net
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License
 */
package net.codestory.http.reload;

import net.codestory.http.*;
import net.codestory.http.io.*;
import net.codestory.http.routes.*;

/**
 * @author <a href="mailto:nicolas.deloof@gmail.com">Nicolas De Loof</a>
 */
public class ConfigurationReloadingProxy implements Configuration {
  private final String fqcn;
  private final ClassLoader parent;

  public ConfigurationReloadingProxy(Class<? extends Configuration> configuration) {
    this.fqcn = configuration.getName();
    this.parent = getClass().getClassLoader();
  }

  @Override
  public void configure(Routes routes) {
    try {
      ClassLoader classLoader = new ParentLastClassLoader(Resources.classesOutputPath(), parent);

      Class<? extends Configuration> type = (Class<? extends Configuration>) classLoader.loadClass(fqcn);
      type.newInstance().configure(routes);
    } catch (Exception e) {
      throw new IllegalStateException("Failed to reload Configuration from classpath", e);
    }
  }
}

==> http-2.28-sources.jar: net/codestory/http/reload/ConfigurationReloadingProxy.java <==
/**
 * Copyright (C) 2013 all@code-story.net
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License
 */
package net.codestory.http.reload;

import net.codestory.http.*;
import net.codestory.http.routes.*;

/**
 * @author <a href="mailto:nicolas.deloof@gmail.com">Nicolas De Loof</a>
 */
public class ConfigurationReloadingProxy implements Configuration {
  private final String fqcn;
  private final ClassLoader parent;

  public ConfigurationReloadingProxy(Class<? extends Configuration> configuration) {
    this.fqcn = configuration.getName();
    this.parent = getClass().getClassLoader();
  }

  @Override
  public void configure(Routes routes) {
    try {
      ClassLoader classLoader = new ParentLastClassLoader(parent);

      Class<? extends Configuration> type = (Class<? extends Configuration>) classLoader.loadClass(fqcn);
      type.newInstance().configure(routes);
    } catch (Exception e) {
      throw new IllegalStateException("Failed to reload Configuration from classpath", e);
    }
  }
}
